# AxeProfiler

[![GNU GPLv3 license](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://github.com/Celshade/AxeProfiler/blob/develop/COPYING)
[![built with Python3](https://img.shields.io/badge/built%20with-Python3-green.svg)](https://www.python.org/)


_AxeProfiler provides a convenient CLI to create/save/apply AxeOS miner configs._

Navigate through a clean and simple CLI to create, save, and then apply various
AxeOS configurations - all from your keyboard. No more tedious clicking through
every device dashboard!
![](demo.gif)

## Requirements
* [python](https://www.python.org/downloads/) >= 3.11
  * requests >= 2.32.5
  * rich >= 14.2.0

## Installation
### [The Way of the Plebb]
Coming soon... ⌛

### [The Way of the Dev]
Clone the repo and run `pip install -e .` from the project root directory. This
should install all dependencies and add the `axeprof` command to PATH - allowing
you to call the program from anywhere with that pip environment active.
```
(venv) <axeprofiler_directory>$ pip install -e .
(venv) $ axeprof
```

You can also install the package from PYPI\
(🐛 may cause a non-critical bug with showing the initial copyright notice)
```
(venv) $ python -m pip install axeprofiler
(venv) $ axeprof
```
Once installed, you may also start the program from inside a python REPL by
importing the entry-point function.
```
>>> # inside REPL
>>> from axeprofiler.__main__ import main
>>> main()
```
## Notes
* This project is still in active development, and it's possible a few hidden
bugs linger (though, they are actively hunted down).
* While there are confirmation prompts, please do your due diligence to know
which device (IP) you are applying a profile to.
* Deleting a [selected] profile does not remove the configuration from an active
miner running it.

---
_While not expected, any tips/donations [in bitcoin] are greatly appreciated_
_and go a long way in supporting me and my future contributions to this_
_codebase and the bitcoin ecosystem in general. If you feel inclined to do so,_
_please send to the secured address below. Much love <3_

Addr: bc1q4fnuqgy4xlqgw3et76nqwz8u573xyhcgwmac8u
